You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tapestry.apache.org by hl...@apache.org on 2012/04/16 19:58:22 UTC

svn commit: r1326703 [1/2] - in /tapestry/tapestry5/trunk/tapestry-core: ./ src/main/java/org/apache/tapestry5/corelib/components/ src/main/java/org/apache/tapestry5/services/ src/main/resources/org/apache/tapestry5/ src/main/resources/org/apache/tapes...

Author: hlship
Date: Mon Apr 16 17:58:21 2012
New Revision: 1326703

URL: http://svn.apache.org/viewvc?rev=1326703&view=rev
Log:
Consolodate ValidationMessages and component messages catalogs into a single core message bundle

Added:
    tapestry/tapestry5/trunk/tapestry-core/mergeprops.groovy   (with props)
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_bg.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_da.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_de.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_el.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_es.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fi_FI.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fr_FR.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_hr.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_it.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ja.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_mk_MK.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_nl.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_no_NB.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_pt_BR.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ru.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sr_RS.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sv_SE.properties
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_zh_CN.properties
Modified:
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Alerts.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/DateField.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Errors.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridColumns.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridPager.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Palette.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/ProgressiveDisplay.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/PropertyEditor.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/BeanEditForm.tml
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Palette.tml
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/ProgressiveDisplay.tml
    tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/corelib/components/PropertyEditorTest.java
    tapestry/tapestry5/trunk/tapestry-core/src/test/resources/org/apache/tapestry5/integration/app1/pages/OverrideDateFieldMessageCatalogDemo.properties

Added: tapestry/tapestry5/trunk/tapestry-core/mergeprops.groovy
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/mergeprops.groovy?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/mergeprops.groovy (added)
+++ tapestry/tapestry5/trunk/tapestry-core/mergeprops.groovy Mon Apr 16 17:58:21 2012
@@ -0,0 +1,118 @@
+import groovy.io.FileType
+
+import java.util.regex.Pattern
+
+// TODO: Before final release ... delete the individual files merged together by this script, then delete this script.
+
+// Script should be executed from the tapestry-core folder, i.e.
+// groovy mergeprops.groovy
+
+locales = ["bg", "da", "de", "el", "es", "fi_FI", "fr_FR", "hr", "it", "ja", "mk_MK", "nl", "no_NB", "pt_BR", "ru", "sr_RS", "sv_SE", "zh_CN"]
+root = "src/main/resources/org/apache/tapestry5"
+
+// Replacement property keys:
+subs = [
+        "default-banner": "core-default-error-banner",
+        "nesting-not-allowed": "core-form-nesting-not-allowed",
+        "invalid-request": "core-invalid-form-request",
+        "available-label": "core-palette-available-label",
+        "selected-label": "core-palette-selected-label",
+        "select-label": "core-palette-select-label",
+        "deselect-label": "core-palette-deselect-label",
+        "up-label": "core-palette-up-label",
+        "down-label": "core-palette-down-label"
+]
+
+// For each locale, we're going to merge in the contents of several files.
+// $root/internal/ValidationMessages[suffix].properties
+// Then from $root/corelib/components/*[suffix].properties
+// Sometimes files don't exist
+// Output to $root/core[suffix].properties
+
+componentsDir = new File("${root}/corelib/components")
+
+def readProps(file) {
+
+    println "Reading properties from $file"
+
+    Properties props = new Properties()
+
+    if (file.exists()) {
+        file.withInputStream { is -> props.load(is) }
+    }
+
+    result = [:]
+
+    props.keys().each { key ->
+        result[key] = props.get(key)
+    }
+
+    println "Read ${result.size()} properties"
+
+    return result;
+}
+
+def mergeSuffix(suffix) {
+
+    def props = readProps new File("${root}/internal/ValidationMessages${suffix}.properties")
+
+    // Now find the other files. When matching no suffix, exclude any localization. This check would
+    // be more complicated if we support, for example, both fr and fr_BE (where one localization was
+    // a prefix of another).
+
+    componentsDir.eachFileMatch FileType.FILES, Pattern.compile(".*${suffix}\\.properties\$"), { File file ->
+
+        //
+        if (suffix == "" && file.name.contains("_")) { return; }
+
+        def fileProps = readProps file
+
+        fileProps.each { key, value ->
+
+            def newKey = subs.get(key, "core-$key")
+
+            props[newKey] = value
+        }
+    }
+
+    def output = new File("$root/core${suffix}.properties")
+
+    println "Writing ${props.size()} properties to $output"
+
+    output.withWriter "utf-8", { writer ->
+
+        writer.println '''\
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+'''
+
+        props.sort().each { key, value ->
+            writer.println "${key}=${value}"
+        }
+    }
+}
+
+// Now the real work.
+
+// First, no localization suffix
+
+mergeSuffix ""
+
+// Then each locale
+locales.each { mergeSuffix("_" + it) }

Propchange: tapestry/tapestry5/trunk/tapestry-core/mergeprops.groovy
------------------------------------------------------------------------------
    svn:executable = *

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Alerts.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Alerts.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Alerts.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Alerts.java Mon Apr 16 17:58:21 2012
@@ -40,7 +40,7 @@ import org.apache.tapestry5.services.jav
 public class Alerts implements ClientElement
 {
 
-    @Parameter(value="message:dismiss-label", defaultPrefix=BindingConstants.LITERAL)
+    @Parameter(value="message:core-dismiss-label", defaultPrefix=BindingConstants.LITERAL)
     private String dismissText;
 
     @Inject

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2007, 2008, 2009, 2010, 2011 The Apache Software Foundation
+// Copyright 2007, 2008, 2009, 2010, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -54,7 +54,7 @@ public class BeanEditForm implements Cli
     /**
      * The text label for the submit button of the form, by default "Create/Update".
      */
-    @Parameter(value = "message:submit-label", defaultPrefix = BindingConstants.LITERAL)
+    @Parameter(value = "message:core-submit-label", defaultPrefix = BindingConstants.LITERAL)
     @Property
     private String submitLabel;
 

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/DateField.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/DateField.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/DateField.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/DateField.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2007, 2008, 2009, 2010, 2011 The Apache Software Foundation
+// Copyright 2007, 2008, 2009, 2010, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -87,6 +87,7 @@ public class DateField extends AbstractF
      * Used to override the component's message catalog.
      *
      * @since 5.2.0.0
+     * @deprecated Since 5.4; override the global message key "core-date-value-not-parsable" instead (see {@link org.apache.tapestry5.services.messages.ComponentMessagesSource})
      */
     @Parameter("componentResources.messages")
     private Messages messages;
@@ -277,7 +278,7 @@ public class DateField extends AbstractF
                 parsedValue = format.parse(value);
         } catch (ParseException ex)
         {
-            tracker.recordError(this, messages.format("date-value-not-parseable", value));
+            tracker.recordError(this, messages.format("core-date-value-not-parseable", value));
             return;
         }
 

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Errors.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Errors.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Errors.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Errors.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2006, 2007, 2008, 2011 The Apache Software Foundation
+// Copyright 2006, 2007, 2008, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -39,7 +39,7 @@ public class Errors
      * following errors before
      * you may continue.".
      */
-    @Parameter("message:default-banner")
+    @Parameter("message:core-default-error-banner")
     private String banner;
 
     /**

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2006, 2007, 2008, 2009, 2010, 2011 The Apache Software Foundation
+// Copyright 2006, 2007, 2008, 2009, 2010, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -296,7 +296,7 @@ public class Form implements ClientEleme
         FormSupport existing = environment.peek(FormSupport.class);
 
         if (existing != null)
-            throw new TapestryException(messages.get("nesting-not-allowed"), existing, null);
+            throw new TapestryException(messages.get("core-form-nesting-not-allowed"), existing, null);
     }
 
     void beginRender(MarkupWriter writer)
@@ -616,7 +616,7 @@ public class Form implements ClientEleme
         String[] values = request.getParameters(FORM_DATA);
 
         if (!request.getMethod().equals("POST") || values == null)
-            throw new RuntimeException(messages.format("invalid-request", FORM_DATA));
+            throw new RuntimeException(messages.format("core-invalid-form-request", FORM_DATA));
 
         // Due to Ajax (FormInjector) there may be multiple values here, so
         // handle each one individually.

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridColumns.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridColumns.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridColumns.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridColumns.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2007, 2008, 2009, 2011 The Apache Software Foundation
+// Copyright 2007, 2008, 2009, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -213,11 +213,11 @@ public class GridColumns
         switch (getSortForColumn())
         {
             case ASCENDING:
-                return messages.get("ascending");
+                return messages.get("core-ascending");
             case DESCENDING:
-                return messages.get("descending");
+                return messages.get("core-descending");
             default:
-                return messages.get("sortable");
+                return messages.get("core-sortable");
         }
     }
 

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridPager.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridPager.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridPager.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/GridPager.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2007, 2008, 2009, 2010, 2011 The Apache Software Foundation
+// Copyright 2007, 2008, 2009, 2010, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -149,7 +149,7 @@ public class GridPager
 
         Element element = writer.element("a",
                                          "href", zone == null ? link : "#",
-                                         "title", messages.format("goto-page", pageIndex));
+                                         "title", messages.format("core-goto-page", pageIndex));
 
         writer.write(Integer.toString(pageIndex));
         writer.end();

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Palette.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Palette.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Palette.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Palette.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2007, 2008, 2009, 2010, 2011 The Apache Software Foundation
+// Copyright 2007, 2008, 2009, 2010, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -201,7 +201,7 @@ public class Palette extends AbstractFie
      * conditionals and components. The default is the text "Available".
      */
     @Property(write = false)
-    @Parameter(required = true, allowNull = false, value = "message:available-label", defaultPrefix = BindingConstants.LITERAL)
+    @Parameter(required = true, allowNull = false, value = "message:core-palette-available-label", defaultPrefix = BindingConstants.LITERAL)
     private Block availableLabel;
 
     /**
@@ -209,7 +209,7 @@ public class Palette extends AbstractFie
      * conditionals and components. The default is the text "Available".
      */
     @Property(write = false)
-    @Parameter(required = true, allowNull = false, value = "message:selected-label", defaultPrefix = BindingConstants.LITERAL)
+    @Parameter(required = true, allowNull = false, value = "message:core-palette-selected-label", defaultPrefix = BindingConstants.LITERAL)
     private Block selectedLabel;
 
     /**

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/ProgressiveDisplay.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/ProgressiveDisplay.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/ProgressiveDisplay.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/ProgressiveDisplay.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2009, 2010, 2011 The Apache Software Foundation
+// Copyright 2009, 2010, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,28 +14,16 @@
 
 package org.apache.tapestry5.corelib.components;
 
-import java.io.IOException;
-
-import org.apache.tapestry5.BindingConstants;
-import org.apache.tapestry5.Block;
-import org.apache.tapestry5.ComponentResources;
-import org.apache.tapestry5.EventConstants;
-import org.apache.tapestry5.EventContext;
-import org.apache.tapestry5.Link;
-import org.apache.tapestry5.MarkupWriter;
-import org.apache.tapestry5.TrackableComponentEventCallback;
-import org.apache.tapestry5.ajax.MultiZoneUpdate;
-import org.apache.tapestry5.annotations.Environmental;
-import org.apache.tapestry5.annotations.Events;
-import org.apache.tapestry5.annotations.Import;
-import org.apache.tapestry5.annotations.Parameter;
-import org.apache.tapestry5.annotations.SupportsInformalParameters;
+import org.apache.tapestry5.*;
+import org.apache.tapestry5.annotations.*;
 import org.apache.tapestry5.dom.Element;
 import org.apache.tapestry5.ioc.annotations.Inject;
 import org.apache.tapestry5.ioc.internal.util.InternalUtils;
 import org.apache.tapestry5.json.JSONObject;
 import org.apache.tapestry5.services.javascript.JavaScriptSupport;
 
+import java.io.IOException;
+
 /**
  * A component used to implement the <a
  * href="http://en.wikipedia.org/wiki/Progressive_enhancement">progressive
@@ -49,9 +37,9 @@ import org.apache.tapestry5.services.jav
  * {@link org.apache.tapestry5.EventConstants#PROGRESSIVE_DISPLAY} event to inform the container about the (optional)
  * event context. The event handler method may return a renderable object; if not then the component's body is rendered
  * as the partial markup response.
- * 
- * @since 5.1.0.1
+ *
  * @tapestrydoc
+ * @since 5.1.0.1
  */
 @SupportsInformalParameters
 @Import(library = "ProgressiveDisplay.js")
@@ -141,11 +129,12 @@ public class ProgressiveDisplay
 
     /**
      * Returns the body of the ProgressiveDisplay, which is sometimes (in the
-     * context of a {@linkplain MultiZoneUpdate multi-zone update})
+     * context of a
+     * {@linkplain org.apache.tapestry5.services.ajax.AjaxResponseRenderer#addRender(org.apache.tapestry5.ClientBodyElement)} partial page render})
      * the content to be included.
-     * 
-     * @since 5.2.0
+     *
      * @return body of component
+     * @since 5.2.0
      */
     public Block getBody()
     {

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/PropertyEditor.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/PropertyEditor.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/PropertyEditor.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/PropertyEditor.java Mon Apr 16 17:58:21 2012
@@ -1,4 +1,4 @@
-// Copyright 2007, 2008, 2009, 2011 The Apache Software Foundation
+// Copyright 2007, 2008, 2009, 2011, 2012 The Apache Software Foundation
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -278,7 +278,7 @@ public class PropertyEditor
         }
         catch (RuntimeException ex)
         {
-            String message = messages.format("block-error", propertyModel.getPropertyName(), dataType, object, ex);
+            String message = messages.format("core-block-error", propertyModel.getPropertyName(), dataType, object, ex);
 
             throw new TapestryException(message, resources.getLocation(), ex);
         }

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,48 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Asc]
+core-block-error=Unable to locate a block to edit property '%s' (with data type '%s') of object %s: %s
+core-cancel-label=Cancel
+core-date-value-not-parseable=Date value '%s' is not parseable.
+core-default-error-banner=You must correct the following errors before continuing.
+core-descending=[Desc]
+core-dismiss-label=Dismiss all
+core-form-nesting-not-allowed=Form components may not be placed inside other Form components.
+core-goto-page=Go to page %d
+core-invalid-form-request=Forms require that the request method be POST and that the %s query parameter have values.
+core-no-grid-data-to-display=There is no data to display.
+core-palette-available-label=Available
+core-palette-deselect-label=< Deselect
+core-palette-down-label=Move Down
+core-palette-select-label=Select >
+core-palette-selected-label=Selected
+core-palette-up-label=Move Up
+core-progressive-display-loading=Loading ...
+core-sortable=[Sortable]
+core-submit-label=Create/Update
+integer-format-exception=You must provide an integer value for %s.
+invalid-email='%s' is not a valid email address.
+max-integer=%2$s requires a value no larger than %1$d.
+maximum-string-length=You may provide at most %d characters for %s.
+min-integer=%2$s requires a value of at least %1$d. 
+minimum-string-length=You must provide at least %d characters for %s.
+number-format-exception=You must provide a numeric value for %s.
+regexp=%2$s does not match pattern '%1$s'.
+required=You must provide a value for %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_bg.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_bg.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_bg.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_bg.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,40 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Нарастващ]
+core-default-error-banner=Трябва да поправите следните грешки преди да продължите.
+core-descending=[Намаляващ]
+core-goto-page=Към страница %d
+core-palette-available-label=Налични
+core-palette-deselect-label=< Махни
+core-palette-down-label=Надолу
+core-palette-select-label=Избери >
+core-palette-selected-label=Избрани
+core-palette-up-label=Нагоре
+core-sortable=[Подредим]
+core-submit-label=Създай/Промени
+integer-format-exception=Трябва да попълните цяло число за %s.
+invalid-email='%s' е невалиден имейл адрес.
+max-integer=%2$s не може да е повече от %1$d.
+maximum-string-length=Можете да попълните най-много %d символа за %s.
+min-integer=%2$s не може да е по-малко от %1$d. 
+minimum-string-length=Трябва да попълните поне %d символа за %s.
+number-format-exception=Трябва да попълните число за %s.
+regexp=%2$s не пасва на нужния формат '%1$s'.
+required=Трябва да попълните стойност за %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_da.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_da.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_da.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_da.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,44 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Stigende]
+core-cancel-label=Annuller
+core-date-value-not-parseable='%s' er ikke en gyldig dato.
+core-default-error-banner=Du skal rette følgende fejl før du kan fortsætte:
+core-descending=[Faldende]
+core-goto-page=GÃ¥ til side %d
+core-palette-available-label=Tilgængelige
+core-palette-deselect-label=< Fravælg
+core-palette-down-label=Flyt Ned
+core-palette-select-label=Vælg >
+core-palette-selected-label=Valgte
+core-palette-up-label=Flyt Op
+core-sortable=[Sortérbar]
+core-submit-label=Opret/Opdater
+core-#=Copyright 2006 The Apache Software Foundation
+integer-format-exception=%s skal være et heltal.
+invalid-email='%s' er ikke en gyldig e-mail-adresse.
+max-integer=%2$s må højst være %1$d.
+maximum-string-length=%2$s må højst være på %1$d tegn.
+min-integer=%2$s skal være mindst %1$d.
+minimum-string-length=%2$s skal mindst være på %1$d tegn.
+number-format-exception=%s skal være et tal.
+regexp=%2$s opfylder ikke mønstret '%1$s'.
+required=%s skal udfyldes.
+#=Copyright 2006, 2007 The Apache Software Foundation

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_de.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_de.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_de.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_de.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,42 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[aufw.]
+core-cancel-label=Abbrechen
+core-date-value-not-parseable=Datumswert '%s' kann nicht geparst werden.
+core-default-error-banner=Sie müssen folgende Fehler beheben, bevor Sie fortfahren können.
+core-descending=[abw.]
+core-goto-page=Gehe zu Seite %d
+core-palette-available-label=Verfügbar
+core-palette-deselect-label=< Abwählen
+core-palette-down-label=Abwärts
+core-palette-select-label=Auswählen >
+core-palette-selected-label=Ausgewählt
+core-palette-up-label=Aufwärts
+core-sortable=[sortierbar]
+core-submit-label=Anlegen/Ändern
+integer-format-exception=Sie müssen für %s einen ganzzahligen Wert angeben.
+invalid-email='%1$s' ist keine gültige E-Mail Adresse.
+max-integer=Der Wert von %2$s darf höchstens %1$d betragen.
+maximum-string-length=%2$s darf höchstens %1$d Zeichen lang sein.
+min-integer=Der Wert von %2$s muss mindestens %1$d betragen. 
+minimum-string-length=%2$s muss mindestens %1$d Zeichen lang sein.
+number-format-exception=Sie müssen für %s einen numerischen Wert angeben.
+regexp=%2$s stimmt nicht mit dem Muster '%1$s' überein.
+required=Sie müssen einen Wert für %s angeben.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_el.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_el.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_el.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_el.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,42 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Αυξ]
+core-cancel-label=Ακύρωση
+core-date-value-not-parseable=Η τιμή '%s' δεν είναι ημερομηνία.
+core-default-error-banner=Πρέπει να διορθώσετε τα ακόλουθα σφάλματα.
+core-descending=[Φθην]
+core-goto-page=Σελίδα %d
+core-palette-available-label=Διαθέσιμα
+core-palette-deselect-label=< Αποεπιλογή
+core-palette-down-label=Κάτω
+core-palette-select-label=Επιλογή >
+core-palette-selected-label=Επιλεγμένα
+core-palette-up-label=Πάνω
+core-sortable=[Ταξινόμηση]
+core-submit-label=Δημιουργία/Ενημέρωση
+integer-format-exception=Πρέπει να δώσετε ακέραια τιμή για το πεδίο %s.
+invalid-email=Το '%s' δεν είναι σωστή διεύθυνση email.
+max-integer=Το πεδίο %2$s απαιτεί τιμή το πολύ %1$d.
+maximum-string-length=Μπορείτε να συμπληρώσετε το πολύ %d χαρακτήρες για το πεδίο %s.
+min-integer=Το πεδίο %2$s απαιτεί τιμή τουλάχιστον %1$d.
+minimum-string-length=Πρέπει να συμπληρώσετε τουλάχιστον %d χαρακτήρες για το πεδίο %s.
+number-format-exception=Πρέπει να δώσετε αριθμητική τιμή για το πεδίο %s.
+regexp=Το %2$s δεν ταιριάζει στο πρότυπο '%1$s'.
+required=Πρέπει να συμπληρώσετε το πεδίο %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_es.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_es.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_es.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_es.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,40 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Asc]
+core-default-error-banner=Debe corregir los siguientes errores antes de que pueda continuar.
+core-descending=[Desc]
+core-goto-page=Ir a la página %d
+core-palette-available-label=Disponible
+core-palette-deselect-label=< Deseleccionar
+core-palette-down-label=Mover abajo
+core-palette-select-label=Seleccionar >
+core-palette-selected-label=Seleccionado
+core-palette-up-label=Mover arriba
+core-sortable=[Ordenable]
+core-submit-label=Crear/Actualizar
+integer-format-exception='%s' tiene que ser un valor entero.
+invalid-email='%s' no es una dirección de email válida.
+max-integer=%2$s no puede ser mayor que %1$d.
+maximum-string-length=Tiene que ingresar como mucho %d caracteres para %s.
+min-integer=%2$s no puede ser menor que %1$d. 
+minimum-string-length=Tiene que ingresar al menos %d caracteres para %s.
+number-format-exception='%s' tiene que ser un valor numérico.
+regexp=%2$s no coincide con el patrón '%1$s'.
+required=Tiene que ingresar un valor para %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fi_FI.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fi_FI.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fi_FI.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fi_FI.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,40 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Nouseva]
+core-default-error-banner=Korjaa seuraavat virheet ja yritä uudelleen.
+core-descending=[Laskeva]
+core-goto-page=Siirry sivulle %d
+core-palette-available-label=Vaihtoehdot
+core-palette-deselect-label=< Peruuta valinta
+core-palette-down-label=Siirrä alas
+core-palette-select-label=Valitse >
+core-palette-selected-label=Valitut
+core-palette-up-label=Siirrä ylös
+core-sortable=[Järjestettävä]
+core-submit-label=Tallenna
+integer-format-exception="%s" -kentŠn syštteen pitŠŠ olla kokonaisluku.
+invalid-email='%s' ei ole sähköpostiosoite.
+max-integer="%2$s" -kentän arvo saa olla enintään %1$d.
+maximum-string-length=Voit syöttää enintään %d merkkiä "%s" -kenttään.
+min-integer="%2$s" -kentän arvo pitää olla vähintään %1$d. 
+minimum-string-length=Syötä vähintään %d merkkiä "%s" -kenttään.
+number-format-exception="%s" -kentŠn syštteen pitŠŠ olla numero.
+regexp=%2$s ei vastaa merkkijonoa '%1$s'.
+required="%s" -kentästä puuttu syöte.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fr_FR.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fr_FR.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fr_FR.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_fr_FR.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,42 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Asc]
+core-cancel-label=Annuler
+core-date-value-not-parseable=La date '%s' ne peut pas Ítre analysÈe.
+core-default-error-banner=Vous devez corriger ces erreurs avant de poursuivre.
+core-descending=[Desc]
+core-goto-page=Aller page %d
+core-palette-available-label=Disponible
+core-palette-deselect-label=< Déselectionner
+core-palette-down-label=Descendre
+core-palette-select-label=Sélectionner >
+core-palette-selected-label=Sélectionné
+core-palette-up-label=Monter
+core-sortable=[Triable]
+core-submit-label=Créer/Mettre à jour
+integer-format-exception=Vous devez saisir un nombre entier pour %s.
+invalid-email='%s' n'est pas une adresse courriel valide.
+max-integer=%2$s ne doit pas avoir une valeur supérieure à %1$d.
+maximum-string-length=Vous ne pouvez donner que %d caractères maximum pour %s.
+min-integer=%2$s doit avoir la valeur minimale de %1$d. 
+minimum-string-length=Vous devez donner au moins %d caractères pour %s.
+number-format-exception=Vous devez saisir un nombre pour %s.
+regexp=%2$s ne correspond pas a l'expression '%1$s'.
+required=Vous devez fournir une valeur pour %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_hr.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_hr.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_hr.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_hr.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,38 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Uzlazno]
+core-default-error-banner=Morate ispraviti slijdeæe greške prije nastavka.
+core-descending=[Silazno]
+core-goto-page=Prijeði na stranicu %d
+core-palette-available-label=Dostupno
+core-palette-deselect-label=< Vrati
+core-palette-down-label=Pomjeri dolje
+core-palette-select-label=Odaberi >
+core-palette-selected-label=Odabrano
+core-palette-up-label=Pomjeri gore
+core-sortable=[Rasporedivo]
+core-submit-label=Spremi
+invalid-email='%s' nije valjana e-mail addresa.
+max-integer=Vrijednost %2$s ne mije biti veća od %1$d.
+maximum-string-length=Možete upisati najviše %d znakova za %s.
+min-integer=Vrijednost %2$s ne smije biti manja od %1$d. 
+minimum-string-length=Morate upisati barem %d znakova za %s.
+regexp=%2$s je potrebno upisati u sljedećem obliku: '%1$s'.
+required=Morate upisati %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_it.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_it.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_it.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_it.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,42 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Asc]
+core-cancel-label=Annulla
+core-date-value-not-parseable=Il valore '%s' non è una data accettabile.
+core-default-error-banner=Per poter proseguire è necessario correggere gli errori seguenti.
+core-descending=[Disc]
+core-goto-page=Vai alla pagina %d
+core-palette-available-label=Disponibili
+core-palette-deselect-label=< Deseleziona
+core-palette-down-label=Sposta in giù
+core-palette-select-label=Seleziona >
+core-palette-selected-label=Selezionati
+core-palette-up-label=Sposta in su
+core-sortable=[Ordinabile]
+core-submit-label=Crea/Aggiorna
+integer-format-exception=Il campo %s richiede un numero intero.
+invalid-email='%s' non è un indirizzo email valido.
+max-integer=Il campo %2$s deve essere minore di %1$d.
+maximum-string-length=Il campo %2$s può contenere al massimo %1$d caratteri.
+min-integer=Il campo %2$s deve essere maggiore di %1$d.
+minimum-string-length=Il campo %2$s deve contenere almeno %1$d caratteri.
+number-format-exception=Il campo %s richiede un valore numerico.
+regexp=%2$s non soddisfa la regola '%1$s'.
+required=Il campo %s deve essere valorizzato.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ja.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ja.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ja.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ja.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,40 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[昇順]
+core-default-error-banner=先へ進むためには以下の誤りを訂正する必要があります。
+core-descending=[降順]
+core-goto-page=%dページ目へ
+core-palette-available-label=未選択
+core-palette-deselect-label=< 選択解除
+core-palette-down-label=下へ
+core-palette-select-label=選択 >
+core-palette-selected-label=選択済
+core-palette-up-label=上へ
+core-sortable=[並べ替え]
+core-submit-label=作成/更新
+integer-format-exception=%sには整数を入力してください。
+invalid-email='%s' はEメールアドレスとして正しくありません。
+max-integer=%2$sには%1$d以下の数を入力してください。
+maximum-string-length=%2$sは%1$d文字以下で入力してください。
+min-integer=%2$sには%1$d以上の数を入力してください。
+minimum-string-length=%2$sには%1$d文字以上入力してください。
+number-format-exception=%sには数値を入力してください。
+regexp=%2$sはパターン '%1$s' にマッチしません。
+required=%sを入力してください。

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_mk_MK.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_mk_MK.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_mk_MK.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_mk_MK.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,42 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Растечки]
+core-cancel-label=Откажи
+core-date-value-not-parseable=Внесениот датум '%s' не е валиден.
+core-default-error-banner=Потребно е да ги поправите следните грешки пред да продолжите.
+core-descending=[Опаѓачки]
+core-goto-page=Премини на страница %d
+core-palette-available-label=Достапни
+core-palette-deselect-label=< Поништи избор
+core-palette-down-label=Помести надолу
+core-palette-select-label=Избери >
+core-palette-selected-label=Избрани
+core-palette-up-label=Помести нагоре
+core-sortable=[Подредливо]
+core-submit-label=Креирај/Ажурирај
+integer-format-exception=Потребно е да внесете целобројна вредност во полето '%s'.
+invalid-email=Потребна е валидна e-mail адреса за полето '%s'.
+max-integer=Не може да внесете поголема вредност од %1$d во полето '%2$s'.
+maximum-string-length=Може да внесете најмногу %d карактери во полето '%s'.
+min-integer=Не може да внесете помала вредност од %1$d во полето '%2$s'. 
+minimum-string-length=Морa да внесете барем %d карактери во полето '%s'.
+number-format-exception=Потребно е да внесете нумеричка вредност во полето '%s'.
+regexp=Во полето '%2$s' е потребно да се внесе вредност што е во обликот '%1$s'.
+required='%s' е задолжително поле.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_nl.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_nl.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_nl.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_nl.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,42 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Oplopend]
+core-cancel-label=Annuleren
+core-date-value-not-parseable=De datum '%s' is niet herkend.
+core-default-error-banner=Verhelp de volgende foutmeldingen om door te kunnen gaan.
+core-descending=[Aflopend]
+core-goto-page=Ga naar pagina %d
+core-palette-available-label=Beschikbaar
+core-palette-deselect-label=< Deselecteer
+core-palette-down-label=Omlaag
+core-palette-select-label=Selecteer >
+core-palette-selected-label=Geselecteerd
+core-palette-up-label=Omhoog
+core-sortable=[Sorteerbaar]
+core-submit-label=Opslaan
+integer-format-exception=%s moet een geheel getal zijn.
+invalid-email='%s' is geen juist e-mailadres.
+max-integer=%2$s mag maximaal %1$d zijn.
+maximum-string-length=%2$s mag maximaal %1$d karakters bevatten.
+min-integer=%2$s moet minimaal %1$d zijn. 
+minimum-string-length=%2$s moet ten minste %1$d karakters bevatten.
+number-format-exception=%s moet een getal zijn.
+regexp=%2$s komt niet overeen met '%1$s'.
+required=%s is een verplicht veld.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_no_NB.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_no_NB.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_no_NB.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_no_NB.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,45 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Økende]
+core-cancel-label=Avbryt
+core-date-value-not-parseable=Klarte ikke å konvertere '%s' til en gyldig dato.
+core-default-error-banner=Du må rette de følgende feilene før du kan fortsette
+core-descending=[Synkende]
+core-dismiss-label=Steng alle
+core-goto-page=GÃ¥ til side %d
+core-no-grid-data-to-display=Ingen data.
+core-palette-available-label=Tilgjengelige
+core-palette-deselect-label=< Fjern valg
+core-palette-down-label=Flytt ned
+core-palette-select-label=Velg >
+core-palette-selected-label=Valgte
+core-palette-up-label=Flytt opp
+core-progressive-display-loading=Laster ...
+core-sortable=[Sorterbar]
+core-submit-label=Opprett/Oppdater
+integer-format-exception=Du må fylle inn et heltall i %s.
+invalid-email='%s' er ikke en gyldig epost adresse.
+max-integer=%2$s må ikke være større enn %1$d.
+maximum-string-length=Du kan ikke bruke mer enn %d tegn i %s.
+min-integer=%2$s må være minst %1$d. 
+minimum-string-length=Du må bruke minst %d tegn i %s.
+number-format-exception=Du må sette inn et tall i %s.
+regexp=%2$s passer ikke til mønsteret '%1$s'.
+required=Du må skrive noe i %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_pt_BR.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_pt_BR.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_pt_BR.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_pt_BR.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,40 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Ascendente]
+core-default-error-banner=Você deve corrigir os seguintes erros antes de continuar.
+core-descending=[Descendente]
+core-goto-page=Ir para a página %d
+core-palette-available-label=Disponíveis
+core-palette-deselect-label=< Remover
+core-palette-down-label=Para baixo
+core-palette-select-label=Selecionar >
+core-palette-selected-label=Selecionados
+core-palette-up-label=Para cima
+core-sortable=[Ordenável]
+core-submit-label=Criar/Atualizar
+integer-format-exception=Você deve fornecer um número inteiro para %s.
+invalid-email='%s' não é um e-mail válido.
+max-integer=%2$s deve ser menor ou igual a %1$d.
+maximum-string-length=Você deve fornecer até %d caracteres para %s.
+min-integer=%2$s deve ser igual ou maior que %1$d.
+minimum-string-length=Você deve fornecer ao menos %d caracteres para %s.
+number-format-exception=Você deve fornecer um número para %s.
+regexp=%2$s não atende ao padrão '%1$s'.
+required=Você deve fornecer um valor para %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ru.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ru.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ru.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_ru.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,42 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[По возрастанию]
+core-cancel-label=Отменить
+core-date-value-not-parseable='%s' недействительная дата.
+core-default-error-banner=Вы должны исправить следующие ошибки прежде, чем продолжить.
+core-descending=[По убыванию]
+core-goto-page=На страницу %d
+core-palette-available-label=Существующие
+core-palette-deselect-label=< Удалить
+core-palette-down-label=Вниз
+core-palette-select-label=Выбрать >
+core-palette-selected-label=Выбранные
+core-palette-up-label=Вверх
+core-sortable=[Упорядочить]
+core-submit-label=Создать/Изменить
+integer-format-exception=Значение для %s не является целым числом.
+invalid-email='%s' недействительный адрес электронной почты.
+max-integer=%2$s не должно быть больше чем %1$d.
+maximum-string-length=Вы можете ввести не более %d символов для %s.
+min-integer=%2$s не должно быть меньше чем %1$d. 
+minimum-string-length=Вы должны ввести не менее %d символов для %s.
+number-format-exception=Значение для %s не является числом.
+regexp=%2$s не соответствует требуемому шаблону '%1$s'.
+required=Вы должны указать значение для %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sr_RS.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sr_RS.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sr_RS.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sr_RS.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,42 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[Rastuće]
+core-cancel-label=Odustani
+core-date-value-not-parseable=Datum '%s' se ne može parsirati.
+core-default-error-banner=Morate ispraviti sledeće greške pre nego što nastavite.
+core-descending=[Opadajuće]
+core-goto-page=Idi na stranu %d
+core-palette-available-label=Dostupno
+core-palette-deselect-label=< Poništi
+core-palette-down-label=Pomeri dole
+core-palette-select-label=Izaberi >
+core-palette-selected-label=Izabrano
+core-palette-up-label=Pomeri gore
+core-sortable=[Sortabilno]
+core-submit-label=Kreiraj/Ažuriraj
+integer-format-exception=Morate uneti celobrojnu vrednost za %s.
+invalid-email='%s' nije validna email adresa.
+max-integer=%2$s ne može imati vrednost veću od %1$d.
+maximum-string-length=Možete uneti najviše %d karaktera za %s.
+min-integer=%2$s može imati najmanje vrednost %1$d. 
+minimum-string-length=Morate uneti bar %d karaktera za %s.
+number-format-exception=Morate uneti brojnu vrednost za %s.
+regexp=%2$s se ne poklapa sa paternom '%1$s'.
+required=Morate uneti vrednost za %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sv_SE.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sv_SE.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sv_SE.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_sv_SE.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,38 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=Stigande ordning
+core-default-error-banner=Du måste rätta följande fel innan du kan fortsätta.
+core-descending=Fallande ordning
+core-goto-page=Navigera till sida %d
+core-palette-available-label=Tillgängliga
+core-palette-deselect-label=< Välj bort
+core-palette-down-label=Flytta ner
+core-palette-select-label=Välj >
+core-palette-selected-label=Valda
+core-palette-up-label=Flytta upp
+core-sortable=Sorterbar
+core-submit-label=Skapa/Uppdatera
+invalid-email='%s' är inte en korrekt formad email-adress.
+max-integer=%2$s får inte vara större än %1$d.
+maximum-string-length=Du får max ange %d tecken för %s.
+min-integer=%2$s måste vara större eller lika med %1$d. 
+minimum-string-length=Du måste ange minst %d tecken för %s.
+regexp=%2$s matchar inte mönstret '%1$s'.
+required=Du måste ange ett värde för %s.

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_zh_CN.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_zh_CN.properties?rev=1326703&view=auto
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_zh_CN.properties (added)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core_zh_CN.properties Mon Apr 16 17:58:21 2012
@@ -0,0 +1,46 @@
+# Copyright 2012 The Apache Software Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+# We try to keep the validation messages consistent, with the constraint
+# value (if applicable) as the first parameter, and the field's label as the
+# second parameter. Occasionally we must use specific indexing when that's
+# not the best order.
+
+core-ascending=[升序]
+core-block-error=找不到编辑属性 '%s'(数据类型为'%s') 的 Block,该 属性属于对象 %s: %s .
+core-date-value-not-parseable=日期 '%s' 不可解析.
+core-default-error-banner=在你继续之前,必须纠正如下错误.
+core-descending=[降序]
+core-form-nesting-not-allowed=Form 组件不能放在其它 Form 组件内部.
+core-goto-page=跳到页面 %d
+core-invalid-form-request=Form 需要请求方法为 POST 并且参数 %s 必须有值.
+core-no-grid-data-to-display=没有可显示的数据.
+core-palette-available-label=可选择
+core-palette-deselect-label=< 删除
+core-palette-down-label=下移
+core-palette-select-label=选择 >
+core-palette-selected-label=已选择
+core-palette-up-label=上移
+core-progressive-display-loading=加载 ...
+core-sortable=[可排序]
+core-submit-label=创建/更新
+integer-format-exception=您必须为 %s 输入整数。
+invalid-email='%s' 不是正确的邮件格式。
+max-integer=%2$s 需要小于 %1$d 的值。
+maximum-string-length=您最多能为 %s 提供至少 %d 字符。
+min-integer=%2$s 需要大于 %1$d 的值。 
+minimum-string-length=您必须为 %s 提供至少 %d 字符。
+number-format-exception=您必须为 %s 提供数字。
+regexp=%2$s 未能匹配模式 '%1$s'。
+required=您必须填写 %s 的值。

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/BeanEditForm.tml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/BeanEditForm.tml?rev=1326703&r1=1326702&r2=1326703&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/BeanEditForm.tml (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/BeanEditForm.tml Mon Apr 16 17:58:21 2012
@@ -9,7 +9,7 @@
         <div class="t-beaneditor-row">
             <input type="submit" class="t-beaneditor-submit" value="${submitLabel}"/>
             <t:if test="cancel">
-              <t:submit t:id="cancel" mode="cancel" value="message:cancel-label"/>
+              <t:submit t:id="cancel" mode="cancel" value="message:core-cancel-label"/>
             </t:if>
         </div>
     </div>
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java Mon Apr 16 17:58:21 2012
@@ -2729,8 +2729,8 @@ public final class TapestryModule
      * <dl>
      * <dt>AppCatalog</dt>
      * <dd>The Resource defined by {@link SymbolConstants#APPLICATION_CATALOG}</dd>
      * <dt>ValidationMessages</dt>
      * <dd>Messages used by validators (before:AppCatalog)</dd>
      * <dt>
      *
      * @since 5.2.0
@@ -2739,8 +2739,8 @@ public final class TapestryModule
                                                          @Symbol(SymbolConstants.APPLICATION_CATALOG)
                                                          Resource applicationCatalog, OrderedConfiguration<Resource> configuration)
     {
-        configuration.add("ValidationMessages",
-                assetSource.resourceForPath("org/apache/tapestry5/internal/ValidationMessages.properties"),
+        configuration.add("Core",
+                assetSource.resourceForPath("org/apache/tapestry5/core.properties"),
                 "before:AppCatalog");
         configuration.add("AppCatalog", applicationCatalog);
     }
@@ -2729,8 +2729,8 @@ public final class TapestryModule
      * <dt>AppCatalog</dt>
      * <dd>The Resource defined by {@link SymbolConstants#APPLICATION_CATALOG}</dd>
-     * <dt>ValidationMessages</dt>
-     * <dd>Messages used by validators (before:AppCatalog)</dd>
+     * <dt>Core</dt>
+     * <dd>Built in messages used by Tapestry's default validators and components (before:AppCatalog)</dd>
      * <dt>
      *

Added: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry5/core.properties?rev=1326703&view=auto
==============================================================================